@@ -36,7 +36,7 @@ class R10K::Git::Rugged::BareRepository < R10K::Git::Rugged::BaseRepository
     @_rugged_repo = ::Rugged::Repository.init_at(@path.to_s, true).tap do |repo|
       config = repo.config
       config['remote.origin.url']    = remote
-      config['remote.origin.fetch']  = '+refs/*:refs/*'
+      config['remote.origin.fetch']  = '+refs/heads/*:refs/heads/*'
       config['remote.origin.mirror'] = 'true'
     end
 
@@ -56,11 +56,12 @@ class R10K::Git::Rugged::BareRepository < R10K::Git::Rugged::BaseRepository
       logger.warn { _("Rugged versions prior to 0.24.0 do not support pruning stale branches during fetch, please upgrade your \'rugged\' gem. (Current version is: %{version})") % {version: Rugged::Version} }
     end
 
-    options = {:credentials => credentials, :prune => true}
-    refspecs = ['+refs/*:refs/*']
-
     remote = remotes[remote_name]
     proxy = R10K::Git.get_proxy_for_remote(remote)
+
+    options = {:credentials => credentials, :prune => true, :proxy_url => proxy, :download_tags => true}
+    refspecs = ['+refs/heads/*:refs/heads/*', '+refs/tags/*:refs/tags/*']
+
     results = nil
 
     R10K::Git.with_proxy(proxy) do
